<?php
/**
 * popup menu for adding new items from topbar
 *
 */

elgg_register_event_handler('init', 'system', 'add_item_menu_init');

if (!function_exists('get_valid_types'))
{
    function get_valid_types($invalid_types) { // return object entity types in the system
        $registered_entities = elgg_get_config('registered_entities');
        $subtypes = array();
        foreach ($registered_entities['object'] as $subtype) {
            if ($subtype == 'page')
            {
                if (!in_array('page_top',$invalid_types))
                {
                     $nice_name = get_nice_name_for_subtype('page_top');
                     $subtypes[$nice_name] = 'page_top';
                }
            }

            if (!in_array($subtype,$invalid_types))
            {
                $nice_name = get_nice_name_for_subtype($subtype);
                $subtypes[$nice_name] = $subtype;
            }
        }
        return $subtypes;
    }
}

function add_item_menu_init() {
    if (elgg_is_logged_in())
    {
        // extend css
        elgg_extend_view("elgg.css", "add_items_menu/css");
        // Add hidden popup module to topbar
        elgg_extend_view('page/elements/topbar', 'add_items_menu/popup');
        elgg_register_plugin_hook_handler('register', 'menu:topbar', 'add_items_topbar_menu_setup');
	}
}

/**
 * Add new items menu icon to topbar menu
 *
 * The menu item opens a popup module defined in view add_items_menu/popup
 *
 * @param string         $hook   Hook name
 * @param string         $type   Hook type
 * @param ElggMenuItem[] $return Array of menu items
 * @param array          $params Hook parameters
 * @return ElggMenuItem[] $return
 */
function add_items_topbar_menu_setup ($hook, $type, $return, $params) {

    $tooltip = elgg_echo("add_items_menu:menu_title");

    $text = '<span class="elgg-icon elgg-icon-round-plus fa fa-plus-circle">' . $text . '</span>';

    $item = ElggMenuItem::factory(array(
        'name' => 'add_items',
        'href' => '#add-items-popup',
        'text' => $text,
        'priority' => 1000,
        'title' => $tooltip,
        'rel' => 'popup',
        'id' => 'add-items-popup-link',
        'data-position' => json_encode([
           'my' => 'left top',
           'at' => 'left bottom',
        ]),
    ));

    $return[] = $item;
    return $return;
}

// get_nice_name_for_subtype - retrieves the elgg text label (singular) for a given subtype

if (!function_exists('get_nice_name_for_subtype'))
{
        function get_nice_name_for_subtype($subtype)
        {
                switch($subtype)
                {
                    case 'image':
                    case 'album':
                    case 'au_set':
                    case 'page_top':
                    case 'pages':
                    case 'bookmarks':
                    case 'videolist_item':
                    {
                        $type_label = elgg_echo ($subtype);
                        break;
                    }
                    case 'file':
                    case 'blog':
                    {
                        $type_label = elgg_echo ($subtype . ':' . $subtype);
                        break;
                    }
                    default:
                    {
                        $type_label = elgg_echo('item:object:' . $subtype);
                        break;
                    }
                }
                return $type_label;
        }
}
